<?php

namespace Islhd\Site\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Islhd\Site\Http\Requests\CenterRequest;
use Islhd\Site\Interfaces\CenterRepositoryInterface;
use Islhd\Site\Models\Center;
use Islhd\Site\Forms\Center as Form;

/**
 * APIController  class for center.
 */
class CenterAPIController extends BaseController
{

    /**
     * Initialize center resource controller.
     *
     * @param type CenterRepositoryInterface $center
     *
     * @return null
     */
    public function __construct(CenterRepositoryInterface $center)
    {
        parent::__construct();
        $this->repository = $center;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Islhd\Site\Repositories\Criteria\CenterResourceCriteria::class);
    }

    /**
     * Display a list of center.
     *
     * @return Response
     */
    public function index(CenterRequest $request)
    {
        return $this->repository
            ->setPresenter(\Islhd\Site\Repositories\Presenter\CenterPresenter::class)
            ->paginate();
    }

    /**
     * Display center.
     *
     * @param Request $request
     * @param Model   $center
     *
     * @return Response
     */
    public function show(CenterRequest $request, Center $center)
    {
        return $center->setPresenter(\Islhd\Site\Repositories\Presenter\CenterListPresenter::class);
        ;
    }

    /**
     * Create new center.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CenterRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('site::center.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('site/center/' . $center->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('site/center');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the center.
     *
     * @param Request $request
     * @param Model   $center
     *
     * @return Response
     */
    public function update(CenterRequest $request, Center $center)
    {
        try {
            $data = $request->all();

            $center->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('site::center.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('site/center/' . $center->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('site/center/' . $center->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the center.
     *
     * @param Model   $center
     *
     * @return Response
     */
    public function destroy(CenterRequest $request, Center $center)
    {
        try {
            $center->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('site::center.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('site/center/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('site/center/' . $center->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
