<?php

namespace Islhd\Site\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Islhd\Site\Http\Requests\DepartmentRequest;
use Islhd\Site\Interfaces\DepartmentRepositoryInterface;
use Islhd\Site\Models\Department;
use Islhd\Site\Forms\Department as Form;

/**
 * APIController  class for department.
 */
class DepartmentAPIController extends BaseController
{

    /**
     * Initialize department resource controller.
     *
     * @param type DepartmentRepositoryInterface $department
     *
     * @return null
     */
    public function __construct(DepartmentRepositoryInterface $department)
    {
        parent::__construct();
        $this->repository = $department;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Islhd\Site\Repositories\Criteria\DepartmentResourceCriteria::class);
    }

    /**
     * Display a list of department.
     *
     * @return Response
     */
    public function index(DepartmentRequest $request)
    {
        return $this->repository
            ->setPresenter(\Islhd\Site\Repositories\Presenter\DepartmentPresenter::class)
            ->paginate();
    }

    /**
     * Display department.
     *
     * @param Request $request
     * @param Model   $department
     *
     * @return Response
     */
    public function show(DepartmentRequest $request, Department $department)
    {
        return $department->setPresenter(\Islhd\Site\Repositories\Presenter\DepartmentListPresenter::class);
        ;
    }

    /**
     * Create new department.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DepartmentRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('site::department.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('site/department/' . $department->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('site/department');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the department.
     *
     * @param Request $request
     * @param Model   $department
     *
     * @return Response
     */
    public function update(DepartmentRequest $request, Department $department)
    {
        try {
            $data = $request->all();

            $department->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('site::department.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('site/department/' . $department->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('site/department/' . $department->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the department.
     *
     * @param Model   $department
     *
     * @return Response
     */
    public function destroy(DepartmentRequest $request, Department $department)
    {
        try {
            $department->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('site::department.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('site/department/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('site/department/' . $department->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
