<?php

namespace Islhd\Site\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Islhd\Site\Http\Requests\DistrictRequest;
use Islhd\Site\Interfaces\DistrictRepositoryInterface;
use Islhd\Site\Models\District;
use Islhd\Site\Forms\District as Form;

/**
 * APIController  class for district.
 */
class DistrictAPIController extends BaseController
{

    /**
     * Initialize district resource controller.
     *
     * @param type DistrictRepositoryInterface $district
     *
     * @return null
     */
    public function __construct(DistrictRepositoryInterface $district)
    {
        parent::__construct();
        $this->repository = $district;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Islhd\Site\Repositories\Criteria\DistrictResourceCriteria::class);
    }

    /**
     * Display a list of district.
     *
     * @return Response
     */
    public function index(DistrictRequest $request)
    {
        return $this->repository
            ->setPresenter(\Islhd\Site\Repositories\Presenter\DistrictPresenter::class)
            ->paginate();
    }

    /**
     * Display district.
     *
     * @param Request $request
     * @param Model   $district
     *
     * @return Response
     */
    public function show(DistrictRequest $request, District $district)
    {
        return $district->setPresenter(\Islhd\Site\Repositories\Presenter\DistrictListPresenter::class);
        ;
    }

    /**
     * Create new district.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DistrictRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('site::district.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('site/district/' . $district->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('site/district');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the district.
     *
     * @param Request $request
     * @param Model   $district
     *
     * @return Response
     */
    public function update(DistrictRequest $request, District $district)
    {
        try {
            $data = $request->all();

            $district->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('site::district.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('site/district/' . $district->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('site/district/' . $district->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the district.
     *
     * @param Model   $district
     *
     * @return Response
     */
    public function destroy(DistrictRequest $request, District $district)
    {
        try {
            $district->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('site::district.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('site/district/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('site/district/' . $district->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
