<?php

namespace Islhd\Site\Policies;

use Litepie\User\Contracts\UserPolicy;
use Islhd\Site\Models\Center;

class CenterPolicy
{

    /**
     * Determine if the given user can view the center.
     *
     * @param UserPolicy $user
     * @param Center $center
     *
     * @return bool
     */
    public function view(UserPolicy $user, Center $center)
    {
        if ($user->canDo('site.center.view') && $user->isAdmin()) {
            return true;
        }

        return $center->user_id == user_id() && $center->user_type == user_type();
    }

    /**
     * Determine if the given user can create a center.
     *
     * @param UserPolicy $user
     * @param Center $center
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('site.center.create');
    }

    /**
     * Determine if the given user can update the given center.
     *
     * @param UserPolicy $user
     * @param Center $center
     *
     * @return bool
     */
    public function update(UserPolicy $user, Center $center)
    {
        if ($user->canDo('site.center.edit') && $user->isAdmin()) {
            return true;
        }

        return $center->user_id == user_id() && $center->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given center.
     *
     * @param UserPolicy $user
     * @param Center $center
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Center $center)
    {
        return $center->user_id == user_id() && $center->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given center.
     *
     * @param UserPolicy $user
     * @param Center $center
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Center $center)
    {
        if ($user->canDo('site.center.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given center.
     *
     * @param UserPolicy $user
     * @param Center $center
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Center $center)
    {
        if ($user->canDo('site.center.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
