<?php

namespace Islhd\Site\Policies;

use Litepie\User\Contracts\UserPolicy;
use Islhd\Site\Models\District;

class DistrictPolicy
{

    /**
     * Determine if the given user can view the district.
     *
     * @param UserPolicy $user
     * @param District $district
     *
     * @return bool
     */
    public function view(UserPolicy $user, District $district)
    {
        if ($user->canDo('site.district.view') && $user->isAdmin()) {
            return true;
        }

        return $district->user_id == user_id() && $district->user_type == user_type();
    }

    /**
     * Determine if the given user can create a district.
     *
     * @param UserPolicy $user
     * @param District $district
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('site.district.create');
    }

    /**
     * Determine if the given user can update the given district.
     *
     * @param UserPolicy $user
     * @param District $district
     *
     * @return bool
     */
    public function update(UserPolicy $user, District $district)
    {
        if ($user->canDo('site.district.edit') && $user->isAdmin()) {
            return true;
        }

        return $district->user_id == user_id() && $district->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given district.
     *
     * @param UserPolicy $user
     * @param District $district
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, District $district)
    {
        return $district->user_id == user_id() && $district->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given district.
     *
     * @param UserPolicy $user
     * @param District $district
     *
     * @return bool
     */
    public function verify(UserPolicy $user, District $district)
    {
        if ($user->canDo('site.district.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given district.
     *
     * @param UserPolicy $user
     * @param District $district
     *
     * @return bool
     */
    public function approve(UserPolicy $user, District $district)
    {
        if ($user->canDo('site.district.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
