<?php

namespace Islhd\Site\Providers;

use Illuminate\Support\ServiceProvider;

class SiteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'site');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'site');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerSite();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerSite()
    {
        $this->app->bind('site', function($app) {
            return new Site($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Site', 'Lavalite\Site\Facades\Site');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('islhd.site', function ($app) {
            return $this->app->make('Islhd\Site\Site');
        });

        // Bind Site to repository
        $this->app->bind(
            'Islhd\Site\Interfaces\SiteRepositoryInterface',
            \Islhd\Site\Repositories\Eloquent\SiteRepository::class
        );        // Bind Department to repository
        $this->app->bind(
            'Islhd\Site\Interfaces\DepartmentRepositoryInterface',
            \Islhd\Site\Repositories\Eloquent\DepartmentRepository::class
        );        // Bind Center to repository
        $this->app->bind(
            'Islhd\Site\Interfaces\CenterRepositoryInterface',
            \Islhd\Site\Repositories\Eloquent\CenterRepository::class
        );        // Bind District to repository
        $this->app->bind(
            'Islhd\Site\Interfaces\DistrictRepositoryInterface',
            \Islhd\Site\Repositories\Eloquent\DistrictRepository::class
        );

        $this->app->register(\Islhd\Site\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Islhd\Site\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and site's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'islhd.site'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeSite::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['islhd.site'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('islhd/site.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/site')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/site')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
